@@ -153,20 +153,35 @@ class CMakeBuildSystem(BuildSystem):
             build_path = os.path.join(self.working_dir, build_path)
             build_path = os.path.realpath(build_path)
 
-        callback = functools.partial(self._add_build_actions,
-                                     context=context,
-                                     package=self.package,
-                                     variant=variant,
-                                     build_type=build_type,
-                                     install=install,
-                                     build_path=build_path,
-                                     install_path=install_path)
+        actions_callback = functools.partial(
+            self._add_build_actions,
+            context=context,
+            package=self.package,
+            variant=variant,
+            build_type=build_type,
+            install=install,
+            build_path=build_path,
+            install_path=install_path
+        )
+
+        post_actions_callback = functools.partial(
+            self.add_pre_build_commands,
+            variant=variant,
+            build_type=build_type,
+            install=install,
+            build_path=build_path,
+            install_path=install_path
+        )
 
         # run the build command and capture/print stderr at the same time
-        retcode, _, _ = context.execute_shell(command=cmd,
-                                              block=True,
-                                              cwd=build_path,
-                                              post_actions_callback=callback)
+        retcode, _, _ = context.execute_shell(
+            command=cmd,
+            block=True,
+            cwd=build_path,
+            actions_callback=actions_callback,
+            post_actions_callback=post_actions_callback
+        )
+
         ret = {}
         if retcode:
             ret["success"] = False
@@ -211,20 +226,26 @@ class CMakeBuildSystem(BuildSystem):
 
         # execute make within the build env
         _pr("\nExecuting: %s" % ' '.join(cmd))
-        retcode, _, _ = context.execute_shell(command=cmd,
-                                              block=True,
-                                              cwd=build_path,
-                                              post_actions_callback=callback)
+        retcode, _, _ = context.execute_shell(
+            command=cmd,
+            block=True,
+            cwd=build_path,
+            actions_callback=actions_callback,
+            post_actions_callback=post_actions_callback
+        )
 
         if not retcode and install and "install" not in cmd:
             cmd.append("install")
 
             # execute make install within the build env
             _pr("\nExecuting: %s" % ' '.join(cmd))
-            retcode, _, _ = context.execute_shell(command=cmd,
-                                                  block=True,
-                                                  cwd=build_path,
-                                                  post_actions_callback=callback)
+            retcode, _, _ = context.execute_shell(
+                command=cmd,
+                block=True,
+                cwd=build_path,
+                actions_callback=actions_callback,
+                post_actions_callback=post_actions_callback
+            )
 
         ret["success"] = (not retcode)
         return ret
@@ -259,18 +280,33 @@ def _FWD__spawn_build_shell(working_dir, build_path, variant_index, install,
     variant = package.get_variant(variant_index)
     config.override("prompt", "BUILD>")
 
-    callback = functools.partial(CMakeBuildSystem._add_build_actions,
-                                 context=context,
-                                 package=package,
-                                 variant=variant,
-                                 build_type=BuildType.local,
-                                 install=install,
-                                 build_path=build_path,
-                                 install_path=install_path)
+    actions_callback = functools.partial(
+        CMakeBuildSystem._add_build_actions,
+        context=context,
+        package=package,
+        variant=variant,
+        build_type=BuildType.local,
+        install=install,
+        build_path=build_path,
+        install_path=install_path
+    )
+
+    post_actions_callback = functools.partial(
+        CMakeBuildSystem.add_pre_build_commands,
+        variant=variant,
+        build_type=BuildType.local,
+        install=install,
+        build_path=build_path,
+        install_path=install_path
+    )
+
+    retcode, _, _ = context.execute_shell(
+        block=True,
+        cwd=build_path,
+        actions_callback=actions_callback,
+        post_actions_callback=post_actions_callback
+    )
 
-    retcode, _, _ = context.execute_shell(block=True,
-                                          cwd=build_path,
-                                          post_actions_callback=callback)
     sys.exit(retcode)
 
 
