@@ -2,7 +2,6 @@ import os
 import re
 from subprocess import PIPE, list2cmdline
 
-from rez.backport.shutilwhich import which
 from rez.config import config
 from rez.rex import RexExecutor, OutputStyle, EscapedString
 from rez.shells import Shell
@@ -136,8 +135,9 @@ class PowerShellBase(Shell):
             # Ensures that the PATHEXT does not append duplicates.
             executor.command(
                 '$Env:PATHEXT = ((($Env:PATHEXT + ";{}") -split ";") | Select-Object -Unique) -join ";"'.format(
-                ";".join(self.settings.additional_pathext)
-            ))
+                    ";".join(self.settings.additional_pathext)
+                )
+            )
 
     def spawn_shell(self,
                     context_file,
